.. _sample_configuration:

-------
Samples
-------

The following sections show sample configuration files for monasca-events-api
and related utilities. These are generated from the code (apart from
the samples for logging and paste) and reflect the current state of code in the
monasca-events-api repository.


.. _sample-configuration-api:

Sample Configuration For Application
------------------------------------

This sample configuration can also be viewed in `events-api.conf.sample
<../_static/events-api.conf.sample>`_.

.. literalinclude:: ../_static/events-api.conf.sample

.. _sample-configuration-logging:

Sample Configuration for Logging
--------------------------------

This sample configuration can also be viewed in `events-api-logging.conf
<../../../etc/monasca/events-api-logging.conf>`_.

.. literalinclude:: ../../../etc/monasca/events-api-logging.conf


Sample Configuration for Paste
------------------------------

This sample configuration can also be viewed in `events-api-paste.ini
<../../../etc/monasca/events-api-paste.ini>`_.

.. literalinclude:: ../../../etc/monasca/events-api-paste.ini


.. _sample-configuration-policies:

Sample Configuration for Policies
---------------------------------

This sample configuration can also be viewed in `events-api.policy.yaml.sample
<../_static/events-api.policy.yaml.sample>`_ .

.. literalinclude:: ../_static/events-api.policy.yaml.sample
